# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_system_profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/voip_system_profile.proto',
  package='voip_system_profile',
  syntax='proto3',
  serialized_options=b'\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profile',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'voltha_protos/voip_system_profile.proto\x12\x13voip_system_profile\x1a\x1cgoogle/api/annotations.proto\"j\n\x18VoipSystemProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x41\n\x11voipSystemProfile\x18\x02 \x01(\x0b\x32&.voip_system_profile.VoipSystemProfile\"{\n\x11VoipSystemProfile\x12\x31\n\tsipConfig\x18\x01 \x01(\x0b\x32\x1e.voip_system_profile.SipConfig\x12\x33\n\nvoipConfig\x18\x02 \x01(\x0b\x32\x1f.voip_system_profile.VoipConfig\"\xab\x03\n\nVoipConfig\x12\x37\n\x0cipHostConfig\x18\x01 \x01(\x0b\x32!.voip_system_profile.IpHostConfig\x12\x37\n\x0ctcpUdpConfig\x18\x02 \x01(\x0b\x32!.voip_system_profile.TcpUdpConfig\x12\x37\n\x0cvoipVoiceCtp\x18\x03 \x01(\x0b\x32!.voip_system_profile.VoipVoiceCtp\x12?\n\x10voipMediaProfile\x18\x04 \x01(\x0b\x32%.voip_system_profile.VoipMediaProfile\x12\x45\n\x13voiceServiceProfile\x18\x05 \x01(\x0b\x32(.voip_system_profile.VoiceServiceProfile\x12\x33\n\nrtpProfile\x18\x06 \x01(\x0b\x32\x1f.voip_system_profile.RtpProfile\x12\x35\n\x0bpptpPotsUni\x18\x07 \x01(\x0b\x32 .voip_system_profile.PptpPotsUni\"\xaf\x01\n\x0cIpHostConfig\x12\x11\n\tipOptions\x18\x01 \x01(\r\x12\x15\n\ronuIdentifier\x18\x02 \x01(\t\x12\x11\n\tipAddress\x18\x03 \x01(\t\x12\x0c\n\x04mask\x18\x04 \x01(\t\x12\x0f\n\x07gateway\x18\x05 \x01(\t\x12\x12\n\nprimaryDns\x18\x06 \x01(\t\x12\x14\n\x0csecondaryDns\x18\x07 \x01(\t\x12\x19\n\x11relayAgentOptions\x18\x08 \x01(\t\"2\n\x0cTcpUdpConfig\x12\x10\n\x08protocol\x18\x01 \x01(\r\x12\x10\n\x08tosField\x18\x02 \x01(\t\"&\n\x0cVoipVoiceCtp\x12\x16\n\x0esignallingCode\x18\x01 \x01(\r\"\x8c\x03\n\x10VoipMediaProfile\x12\x0f\n\x07\x66\x61xMode\x18\x01 \x01(\r\x12\x17\n\x0f\x63odecSelection1\x18\x02 \x01(\r\x12\x1e\n\x16packetPeriodSelection1\x18\x03 \x01(\r\x12\x1b\n\x13silenceSuppression1\x18\x04 \x01(\r\x12\x17\n\x0f\x63odecSelection2\x18\x05 \x01(\r\x12\x1e\n\x16packetPeriodSelection2\x18\x06 \x01(\r\x12\x1b\n\x13silenceSuppression2\x18\x07 \x01(\r\x12\x17\n\x0f\x63odecSelection3\x18\x08 \x01(\r\x12\x1e\n\x16packetPeriodSelection3\x18\t \x01(\r\x12\x1b\n\x13silenceSuppression3\x18\n \x01(\r\x12\x17\n\x0f\x63odecSelection4\x18\x0b \x01(\r\x12\x1e\n\x16packetPeriodSelection4\x18\x0c \x01(\r\x12\x1b\n\x13silenceSuppression4\x18\r \x01(\r\x12\x0f\n\x07oobDtmf\x18\x0e \x01(\r\"\xe4\x01\n\x13VoiceServiceProfile\x12\x18\n\x10\x61nnouncementType\x18\x01 \x01(\r\x12\x14\n\x0cjitterTarget\x18\x02 \x01(\r\x12\x17\n\x0fjitterBufferMax\x18\x03 \x01(\r\x12\x15\n\rechoCancelInd\x18\x04 \x01(\x08\x12\x1b\n\x13pstnProtocolVariant\x18\x05 \x01(\r\x12\x17\n\x0f\x64tmfDigitLevels\x18\x06 \x01(\r\x12\x19\n\x11\x64tmfDigitDuration\x18\x07 \x01(\r\x12\x1c\n\x14hookFlashMinimumTime\x18\x08 \x01(\r\"\x9e\x01\n\nRtpProfile\x12\x14\n\x0clocalPortMin\x18\x01 \x01(\r\x12\x14\n\x0clocalPortMax\x18\x02 \x01(\r\x12\x10\n\x08\x64scpMark\x18\x03 \x01(\t\x12\x17\n\x0fpiggyBackEvents\x18\x04 \x01(\r\x12\x12\n\ntoneEvents\x18\x05 \x01(\r\x12\x12\n\ndtmfEvents\x18\x06 \x01(\r\x12\x11\n\tcasEvents\x18\x07 \x01(\r\"\xcc\x01\n\x0bPptpPotsUni\x12\x0b\n\x03\x61rc\x18\x01 \x01(\t\x12\x13\n\x0b\x61rcInterval\x18\x02 \x01(\t\x12\x11\n\timpedance\x18\x03 \x01(\r\x12\x18\n\x10transmissionPath\x18\x04 \x01(\r\x12\x0e\n\x06rxGain\x18\x05 \x01(\x11\x12\x0e\n\x06txGain\x18\x06 \x01(\x11\x12\x18\n\x10potsHoldOverTime\x18\x07 \x01(\r\x12\x1a\n\x12nominalFeedVoltage\x18\x08 \x01(\r\x12\x18\n\x10lossOfSoftSwitch\x18\t \x01(\r\"\xe6\x02\n\tSipConfig\x12\x35\n\x0bsipUserData\x18\x01 \x01(\x0b\x32 .voip_system_profile.SipUserData\x12;\n\x0esipAgentConfig\x18\x02 \x01(\x0b\x32#.voip_system_profile.SipAgentConfig\x12=\n\x0fnetworkDialPlan\x18\x03 \x01(\x0b\x32$.voip_system_profile.NetworkDialPlan\x12K\n\x16voipFeatureAccessCodes\x18\x04 \x01(\x0b\x32+.voip_system_profile.VoipFeatureAccessCodes\x12Y\n\x1dvoipApplicationServiceProfile\x18\x05 \x01(\x0b\x32\x32.voip_system_profile.VoipApplicationServiceProfile\"\xdd\x01\n\x0bSipUserData\x12\x13\n\x0buserPartAor\x18\x01 \x01(\t\x12\x45\n\x13usernameAndPassword\x18\x02 \x01(\x0b\x32(.voip_system_profile.UsernameAndPassword\x12\x1d\n\x15voicemailServerSipUri\x18\x03 \x01(\t\x12+\n#voicemailSubscriptionExpirationTime\x18\x04 \x01(\x05\x12\x14\n\x0creleaseTimer\x18\x05 \x01(\x05\x12\x10\n\x08rohTimer\x18\x06 \x01(\x05\"\xd9\x02\n\x0eSipAgentConfig\x12\x1c\n\x14outboundProxyAddress\x18\x01 \x01(\t\x12\x15\n\rprimarySipDns\x18\x02 \x01(\t\x12\x17\n\x0fsecondarySipDns\x18\x03 \x01(\t\x12\x15\n\rsipRegExpTime\x18\x04 \x01(\x05\x12\x1d\n\x15sipReregHeadStartTime\x18\x05 \x01(\x05\x12\x14\n\x0cSipRegistrar\x18\x06 \x01(\t\x12\x12\n\nsoftSwitch\x18\x07 \x01(\t\x12?\n\x10sipResponseTable\x18\x08 \x01(\x0b\x32%.voip_system_profile.SipResponseTable\x12 \n\x18sipOptionTransmitControl\x18\t \x01(\x08\x12\x14\n\x0csipUriFormat\x18\n \x01(\t\x12 \n\x18redundantSipAgentPointer\x18\x0b \x01(\t\"\x9d\x01\n\x0fNetworkDialPlan\x12\x1b\n\x13\x63riticalDialTimeout\x18\x01 \x01(\r\x12\x1a\n\x12partialDialTimeout\x18\x02 \x01(\r\x12\x16\n\x0e\x64ialPlanFormat\x18\x03 \x01(\r\x12\x39\n\rdialPlanTable\x18\x04 \x01(\x0b\x32\".voip_system_profile.DialPlanTable\"/\n\x13UsernameAndPassword\x12\x18\n\x10validationScheme\x18\x01 \x01(\x05\"N\n\x10SipResponseTable\x12\x17\n\x0fsipResponseCode\x18\x01 \x01(\t\x12\x0c\n\x04tone\x18\x02 \x01(\t\x12\x13\n\x0btextMessage\x18\x03 \x01(\t\"h\n\rDialPlanTable\x12\x12\n\ndialPlanId\x18\x01 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x02 \x01(\r\x12\x15\n\rdialPlanToken\x18\x03 \x01(\t\x12\x1c\n\x14\x64ialPlanTableMaxSize\x18\x04 \x01(\r\"\xe5\x02\n\x16VoipFeatureAccessCodes\x12\x19\n\x11\x63\x61ncelCallWaiting\x18\x01 \x01(\t\x12\x10\n\x08\x63\x61llHold\x18\x02 \x01(\t\x12\x10\n\x08\x63\x61llPark\x18\x03 \x01(\t\x12\x18\n\x10\x63\x61llerIdActivate\x18\x04 \x01(\t\x12\x1a\n\x12\x63\x61llerIdDeactivate\x18\x05 \x01(\t\x12\x1e\n\x16\x64oNotDisturbActivation\x18\x06 \x01(\t\x12 \n\x18\x64oNotDisturbDeactivation\x18\x07 \x01(\t\x12\x1d\n\x15\x64oNotDisturbPinChange\x18\x08 \x01(\t\x12\x1e\n\x16\x65mergencyServiceNumber\x18\t \x01(\t\x12\x17\n\x0fintercomService\x18\n \x01(\t\x12\x1e\n\x16unattendedCallTransfer\x18\x0b \x01(\t\x12\x1c\n\x14\x61ttendedCallTransfer\x18\x0c \x01(\t\"\xbf\x02\n\x1dVoipApplicationServiceProfile\x12\x13\n\x0b\x63idFeatures\x18\x01 \x01(\r\x12\x1b\n\x13\x63\x61llWaitingFeatures\x18\x02 \x01(\r\x12&\n\x1e\x63\x61llProgressOrTransferFeatures\x18\x03 \x01(\r\x12 \n\x18\x63\x61llPresentationFeatures\x18\x04 \x01(\r\x12\x1c\n\x14\x64irectConnectFeature\x18\x05 \x01(\r\x12\x1f\n\x17\x64irectConnectUriPointer\x18\x06 \x01(\t\x12\"\n\x1a\x62ridgedLineAgentUriPointer\x18\x07 \x01(\t\x12#\n\x1b\x63onferenceFactoryUriPointer\x18\x08 \x01(\t\x12\x1a\n\x12\x64ialToneDelayTimer\x18\t \x01(\rBf\n\'org.opencord.voltha.voip_system_profileZ;github.com/opencord/voltha-protos/v5/go/voip_system_profileb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_VOIPSYSTEMPROFILEREQUEST = _descriptor.Descriptor(
  name='VoipSystemProfileRequest',
  full_name='voip_system_profile.VoipSystemProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voip_system_profile.VoipSystemProfileRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipSystemProfile', full_name='voip_system_profile.VoipSystemProfileRequest.voipSystemProfile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=94,
  serialized_end=200,
)


_VOIPSYSTEMPROFILE = _descriptor.Descriptor(
  name='VoipSystemProfile',
  full_name='voip_system_profile.VoipSystemProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sipConfig', full_name='voip_system_profile.VoipSystemProfile.sipConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipConfig', full_name='voip_system_profile.VoipSystemProfile.voipConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=202,
  serialized_end=325,
)


_VOIPCONFIG = _descriptor.Descriptor(
  name='VoipConfig',
  full_name='voip_system_profile.VoipConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipHostConfig', full_name='voip_system_profile.VoipConfig.ipHostConfig', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcpUdpConfig', full_name='voip_system_profile.VoipConfig.tcpUdpConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipVoiceCtp', full_name='voip_system_profile.VoipConfig.voipVoiceCtp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipMediaProfile', full_name='voip_system_profile.VoipConfig.voipMediaProfile', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voiceServiceProfile', full_name='voip_system_profile.VoipConfig.voiceServiceProfile', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rtpProfile', full_name='voip_system_profile.VoipConfig.rtpProfile', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pptpPotsUni', full_name='voip_system_profile.VoipConfig.pptpPotsUni', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=328,
  serialized_end=755,
)


_IPHOSTCONFIG = _descriptor.Descriptor(
  name='IpHostConfig',
  full_name='voip_system_profile.IpHostConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipOptions', full_name='voip_system_profile.IpHostConfig.ipOptions', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='onuIdentifier', full_name='voip_system_profile.IpHostConfig.onuIdentifier', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ipAddress', full_name='voip_system_profile.IpHostConfig.ipAddress', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mask', full_name='voip_system_profile.IpHostConfig.mask', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gateway', full_name='voip_system_profile.IpHostConfig.gateway', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primaryDns', full_name='voip_system_profile.IpHostConfig.primaryDns', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondaryDns', full_name='voip_system_profile.IpHostConfig.secondaryDns', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relayAgentOptions', full_name='voip_system_profile.IpHostConfig.relayAgentOptions', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=758,
  serialized_end=933,
)


_TCPUDPCONFIG = _descriptor.Descriptor(
  name='TcpUdpConfig',
  full_name='voip_system_profile.TcpUdpConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='voip_system_profile.TcpUdpConfig.protocol', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tosField', full_name='voip_system_profile.TcpUdpConfig.tosField', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=935,
  serialized_end=985,
)


_VOIPVOICECTP = _descriptor.Descriptor(
  name='VoipVoiceCtp',
  full_name='voip_system_profile.VoipVoiceCtp',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signallingCode', full_name='voip_system_profile.VoipVoiceCtp.signallingCode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=987,
  serialized_end=1025,
)


_VOIPMEDIAPROFILE = _descriptor.Descriptor(
  name='VoipMediaProfile',
  full_name='voip_system_profile.VoipMediaProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='faxMode', full_name='voip_system_profile.VoipMediaProfile.faxMode', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codecSelection1', full_name='voip_system_profile.VoipMediaProfile.codecSelection1', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packetPeriodSelection1', full_name='voip_system_profile.VoipMediaProfile.packetPeriodSelection1', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silenceSuppression1', full_name='voip_system_profile.VoipMediaProfile.silenceSuppression1', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codecSelection2', full_name='voip_system_profile.VoipMediaProfile.codecSelection2', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packetPeriodSelection2', full_name='voip_system_profile.VoipMediaProfile.packetPeriodSelection2', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silenceSuppression2', full_name='voip_system_profile.VoipMediaProfile.silenceSuppression2', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codecSelection3', full_name='voip_system_profile.VoipMediaProfile.codecSelection3', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packetPeriodSelection3', full_name='voip_system_profile.VoipMediaProfile.packetPeriodSelection3', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silenceSuppression3', full_name='voip_system_profile.VoipMediaProfile.silenceSuppression3', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codecSelection4', full_name='voip_system_profile.VoipMediaProfile.codecSelection4', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='packetPeriodSelection4', full_name='voip_system_profile.VoipMediaProfile.packetPeriodSelection4', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='silenceSuppression4', full_name='voip_system_profile.VoipMediaProfile.silenceSuppression4', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='oobDtmf', full_name='voip_system_profile.VoipMediaProfile.oobDtmf', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1028,
  serialized_end=1424,
)


_VOICESERVICEPROFILE = _descriptor.Descriptor(
  name='VoiceServiceProfile',
  full_name='voip_system_profile.VoiceServiceProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='announcementType', full_name='voip_system_profile.VoiceServiceProfile.announcementType', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jitterTarget', full_name='voip_system_profile.VoiceServiceProfile.jitterTarget', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jitterBufferMax', full_name='voip_system_profile.VoiceServiceProfile.jitterBufferMax', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='echoCancelInd', full_name='voip_system_profile.VoiceServiceProfile.echoCancelInd', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pstnProtocolVariant', full_name='voip_system_profile.VoiceServiceProfile.pstnProtocolVariant', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtmfDigitLevels', full_name='voip_system_profile.VoiceServiceProfile.dtmfDigitLevels', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtmfDigitDuration', full_name='voip_system_profile.VoiceServiceProfile.dtmfDigitDuration', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hookFlashMinimumTime', full_name='voip_system_profile.VoiceServiceProfile.hookFlashMinimumTime', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1427,
  serialized_end=1655,
)


_RTPPROFILE = _descriptor.Descriptor(
  name='RtpProfile',
  full_name='voip_system_profile.RtpProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localPortMin', full_name='voip_system_profile.RtpProfile.localPortMin', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localPortMax', full_name='voip_system_profile.RtpProfile.localPortMax', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dscpMark', full_name='voip_system_profile.RtpProfile.dscpMark', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='piggyBackEvents', full_name='voip_system_profile.RtpProfile.piggyBackEvents', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='toneEvents', full_name='voip_system_profile.RtpProfile.toneEvents', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dtmfEvents', full_name='voip_system_profile.RtpProfile.dtmfEvents', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='casEvents', full_name='voip_system_profile.RtpProfile.casEvents', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1658,
  serialized_end=1816,
)


_PPTPPOTSUNI = _descriptor.Descriptor(
  name='PptpPotsUni',
  full_name='voip_system_profile.PptpPotsUni',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='arc', full_name='voip_system_profile.PptpPotsUni.arc', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arcInterval', full_name='voip_system_profile.PptpPotsUni.arcInterval', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='impedance', full_name='voip_system_profile.PptpPotsUni.impedance', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transmissionPath', full_name='voip_system_profile.PptpPotsUni.transmissionPath', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rxGain', full_name='voip_system_profile.PptpPotsUni.rxGain', index=4,
      number=5, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txGain', full_name='voip_system_profile.PptpPotsUni.txGain', index=5,
      number=6, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='potsHoldOverTime', full_name='voip_system_profile.PptpPotsUni.potsHoldOverTime', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nominalFeedVoltage', full_name='voip_system_profile.PptpPotsUni.nominalFeedVoltage', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lossOfSoftSwitch', full_name='voip_system_profile.PptpPotsUni.lossOfSoftSwitch', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1819,
  serialized_end=2023,
)


_SIPCONFIG = _descriptor.Descriptor(
  name='SipConfig',
  full_name='voip_system_profile.SipConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sipUserData', full_name='voip_system_profile.SipConfig.sipUserData', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipAgentConfig', full_name='voip_system_profile.SipConfig.sipAgentConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='networkDialPlan', full_name='voip_system_profile.SipConfig.networkDialPlan', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipFeatureAccessCodes', full_name='voip_system_profile.SipConfig.voipFeatureAccessCodes', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipApplicationServiceProfile', full_name='voip_system_profile.SipConfig.voipApplicationServiceProfile', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2026,
  serialized_end=2384,
)


_SIPUSERDATA = _descriptor.Descriptor(
  name='SipUserData',
  full_name='voip_system_profile.SipUserData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='userPartAor', full_name='voip_system_profile.SipUserData.userPartAor', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='usernameAndPassword', full_name='voip_system_profile.SipUserData.usernameAndPassword', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voicemailServerSipUri', full_name='voip_system_profile.SipUserData.voicemailServerSipUri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voicemailSubscriptionExpirationTime', full_name='voip_system_profile.SipUserData.voicemailSubscriptionExpirationTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='releaseTimer', full_name='voip_system_profile.SipUserData.releaseTimer', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rohTimer', full_name='voip_system_profile.SipUserData.rohTimer', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2387,
  serialized_end=2608,
)


_SIPAGENTCONFIG = _descriptor.Descriptor(
  name='SipAgentConfig',
  full_name='voip_system_profile.SipAgentConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outboundProxyAddress', full_name='voip_system_profile.SipAgentConfig.outboundProxyAddress', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primarySipDns', full_name='voip_system_profile.SipAgentConfig.primarySipDns', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondarySipDns', full_name='voip_system_profile.SipAgentConfig.secondarySipDns', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipRegExpTime', full_name='voip_system_profile.SipAgentConfig.sipRegExpTime', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipReregHeadStartTime', full_name='voip_system_profile.SipAgentConfig.sipReregHeadStartTime', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='SipRegistrar', full_name='voip_system_profile.SipAgentConfig.SipRegistrar', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='softSwitch', full_name='voip_system_profile.SipAgentConfig.softSwitch', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipResponseTable', full_name='voip_system_profile.SipAgentConfig.sipResponseTable', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipOptionTransmitControl', full_name='voip_system_profile.SipAgentConfig.sipOptionTransmitControl', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipUriFormat', full_name='voip_system_profile.SipAgentConfig.sipUriFormat', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redundantSipAgentPointer', full_name='voip_system_profile.SipAgentConfig.redundantSipAgentPointer', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2611,
  serialized_end=2956,
)


_NETWORKDIALPLAN = _descriptor.Descriptor(
  name='NetworkDialPlan',
  full_name='voip_system_profile.NetworkDialPlan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='criticalDialTimeout', full_name='voip_system_profile.NetworkDialPlan.criticalDialTimeout', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='partialDialTimeout', full_name='voip_system_profile.NetworkDialPlan.partialDialTimeout', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dialPlanFormat', full_name='voip_system_profile.NetworkDialPlan.dialPlanFormat', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dialPlanTable', full_name='voip_system_profile.NetworkDialPlan.dialPlanTable', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2959,
  serialized_end=3116,
)


_USERNAMEANDPASSWORD = _descriptor.Descriptor(
  name='UsernameAndPassword',
  full_name='voip_system_profile.UsernameAndPassword',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='validationScheme', full_name='voip_system_profile.UsernameAndPassword.validationScheme', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3118,
  serialized_end=3165,
)


_SIPRESPONSETABLE = _descriptor.Descriptor(
  name='SipResponseTable',
  full_name='voip_system_profile.SipResponseTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sipResponseCode', full_name='voip_system_profile.SipResponseTable.sipResponseCode', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tone', full_name='voip_system_profile.SipResponseTable.tone', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='textMessage', full_name='voip_system_profile.SipResponseTable.textMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3167,
  serialized_end=3245,
)


_DIALPLANTABLE = _descriptor.Descriptor(
  name='DialPlanTable',
  full_name='voip_system_profile.DialPlanTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dialPlanId', full_name='voip_system_profile.DialPlanTable.dialPlanId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='action', full_name='voip_system_profile.DialPlanTable.action', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dialPlanToken', full_name='voip_system_profile.DialPlanTable.dialPlanToken', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dialPlanTableMaxSize', full_name='voip_system_profile.DialPlanTable.dialPlanTableMaxSize', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3247,
  serialized_end=3351,
)


_VOIPFEATUREACCESSCODES = _descriptor.Descriptor(
  name='VoipFeatureAccessCodes',
  full_name='voip_system_profile.VoipFeatureAccessCodes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cancelCallWaiting', full_name='voip_system_profile.VoipFeatureAccessCodes.cancelCallWaiting', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callHold', full_name='voip_system_profile.VoipFeatureAccessCodes.callHold', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callPark', full_name='voip_system_profile.VoipFeatureAccessCodes.callPark', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callerIdActivate', full_name='voip_system_profile.VoipFeatureAccessCodes.callerIdActivate', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callerIdDeactivate', full_name='voip_system_profile.VoipFeatureAccessCodes.callerIdDeactivate', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doNotDisturbActivation', full_name='voip_system_profile.VoipFeatureAccessCodes.doNotDisturbActivation', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doNotDisturbDeactivation', full_name='voip_system_profile.VoipFeatureAccessCodes.doNotDisturbDeactivation', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doNotDisturbPinChange', full_name='voip_system_profile.VoipFeatureAccessCodes.doNotDisturbPinChange', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='emergencyServiceNumber', full_name='voip_system_profile.VoipFeatureAccessCodes.emergencyServiceNumber', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intercomService', full_name='voip_system_profile.VoipFeatureAccessCodes.intercomService', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unattendedCallTransfer', full_name='voip_system_profile.VoipFeatureAccessCodes.unattendedCallTransfer', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attendedCallTransfer', full_name='voip_system_profile.VoipFeatureAccessCodes.attendedCallTransfer', index=11,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3354,
  serialized_end=3711,
)


_VOIPAPPLICATIONSERVICEPROFILE = _descriptor.Descriptor(
  name='VoipApplicationServiceProfile',
  full_name='voip_system_profile.VoipApplicationServiceProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cidFeatures', full_name='voip_system_profile.VoipApplicationServiceProfile.cidFeatures', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callWaitingFeatures', full_name='voip_system_profile.VoipApplicationServiceProfile.callWaitingFeatures', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callProgressOrTransferFeatures', full_name='voip_system_profile.VoipApplicationServiceProfile.callProgressOrTransferFeatures', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='callPresentationFeatures', full_name='voip_system_profile.VoipApplicationServiceProfile.callPresentationFeatures', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directConnectFeature', full_name='voip_system_profile.VoipApplicationServiceProfile.directConnectFeature', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='directConnectUriPointer', full_name='voip_system_profile.VoipApplicationServiceProfile.directConnectUriPointer', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bridgedLineAgentUriPointer', full_name='voip_system_profile.VoipApplicationServiceProfile.bridgedLineAgentUriPointer', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='conferenceFactoryUriPointer', full_name='voip_system_profile.VoipApplicationServiceProfile.conferenceFactoryUriPointer', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dialToneDelayTimer', full_name='voip_system_profile.VoipApplicationServiceProfile.dialToneDelayTimer', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3714,
  serialized_end=4033,
)

_VOIPSYSTEMPROFILEREQUEST.fields_by_name['voipSystemProfile'].message_type = _VOIPSYSTEMPROFILE
_VOIPSYSTEMPROFILE.fields_by_name['sipConfig'].message_type = _SIPCONFIG
_VOIPSYSTEMPROFILE.fields_by_name['voipConfig'].message_type = _VOIPCONFIG
_VOIPCONFIG.fields_by_name['ipHostConfig'].message_type = _IPHOSTCONFIG
_VOIPCONFIG.fields_by_name['tcpUdpConfig'].message_type = _TCPUDPCONFIG
_VOIPCONFIG.fields_by_name['voipVoiceCtp'].message_type = _VOIPVOICECTP
_VOIPCONFIG.fields_by_name['voipMediaProfile'].message_type = _VOIPMEDIAPROFILE
_VOIPCONFIG.fields_by_name['voiceServiceProfile'].message_type = _VOICESERVICEPROFILE
_VOIPCONFIG.fields_by_name['rtpProfile'].message_type = _RTPPROFILE
_VOIPCONFIG.fields_by_name['pptpPotsUni'].message_type = _PPTPPOTSUNI
_SIPCONFIG.fields_by_name['sipUserData'].message_type = _SIPUSERDATA
_SIPCONFIG.fields_by_name['sipAgentConfig'].message_type = _SIPAGENTCONFIG
_SIPCONFIG.fields_by_name['networkDialPlan'].message_type = _NETWORKDIALPLAN
_SIPCONFIG.fields_by_name['voipFeatureAccessCodes'].message_type = _VOIPFEATUREACCESSCODES
_SIPCONFIG.fields_by_name['voipApplicationServiceProfile'].message_type = _VOIPAPPLICATIONSERVICEPROFILE
_SIPUSERDATA.fields_by_name['usernameAndPassword'].message_type = _USERNAMEANDPASSWORD
_SIPAGENTCONFIG.fields_by_name['sipResponseTable'].message_type = _SIPRESPONSETABLE
_NETWORKDIALPLAN.fields_by_name['dialPlanTable'].message_type = _DIALPLANTABLE
DESCRIPTOR.message_types_by_name['VoipSystemProfileRequest'] = _VOIPSYSTEMPROFILEREQUEST
DESCRIPTOR.message_types_by_name['VoipSystemProfile'] = _VOIPSYSTEMPROFILE
DESCRIPTOR.message_types_by_name['VoipConfig'] = _VOIPCONFIG
DESCRIPTOR.message_types_by_name['IpHostConfig'] = _IPHOSTCONFIG
DESCRIPTOR.message_types_by_name['TcpUdpConfig'] = _TCPUDPCONFIG
DESCRIPTOR.message_types_by_name['VoipVoiceCtp'] = _VOIPVOICECTP
DESCRIPTOR.message_types_by_name['VoipMediaProfile'] = _VOIPMEDIAPROFILE
DESCRIPTOR.message_types_by_name['VoiceServiceProfile'] = _VOICESERVICEPROFILE
DESCRIPTOR.message_types_by_name['RtpProfile'] = _RTPPROFILE
DESCRIPTOR.message_types_by_name['PptpPotsUni'] = _PPTPPOTSUNI
DESCRIPTOR.message_types_by_name['SipConfig'] = _SIPCONFIG
DESCRIPTOR.message_types_by_name['SipUserData'] = _SIPUSERDATA
DESCRIPTOR.message_types_by_name['SipAgentConfig'] = _SIPAGENTCONFIG
DESCRIPTOR.message_types_by_name['NetworkDialPlan'] = _NETWORKDIALPLAN
DESCRIPTOR.message_types_by_name['UsernameAndPassword'] = _USERNAMEANDPASSWORD
DESCRIPTOR.message_types_by_name['SipResponseTable'] = _SIPRESPONSETABLE
DESCRIPTOR.message_types_by_name['DialPlanTable'] = _DIALPLANTABLE
DESCRIPTOR.message_types_by_name['VoipFeatureAccessCodes'] = _VOIPFEATUREACCESSCODES
DESCRIPTOR.message_types_by_name['VoipApplicationServiceProfile'] = _VOIPAPPLICATIONSERVICEPROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VoipSystemProfileRequest = _reflection.GeneratedProtocolMessageType('VoipSystemProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _VOIPSYSTEMPROFILEREQUEST,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipSystemProfileRequest)
  })
_sym_db.RegisterMessage(VoipSystemProfileRequest)

VoipSystemProfile = _reflection.GeneratedProtocolMessageType('VoipSystemProfile', (_message.Message,), {
  'DESCRIPTOR' : _VOIPSYSTEMPROFILE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipSystemProfile)
  })
_sym_db.RegisterMessage(VoipSystemProfile)

VoipConfig = _reflection.GeneratedProtocolMessageType('VoipConfig', (_message.Message,), {
  'DESCRIPTOR' : _VOIPCONFIG,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipConfig)
  })
_sym_db.RegisterMessage(VoipConfig)

IpHostConfig = _reflection.GeneratedProtocolMessageType('IpHostConfig', (_message.Message,), {
  'DESCRIPTOR' : _IPHOSTCONFIG,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.IpHostConfig)
  })
_sym_db.RegisterMessage(IpHostConfig)

TcpUdpConfig = _reflection.GeneratedProtocolMessageType('TcpUdpConfig', (_message.Message,), {
  'DESCRIPTOR' : _TCPUDPCONFIG,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.TcpUdpConfig)
  })
_sym_db.RegisterMessage(TcpUdpConfig)

VoipVoiceCtp = _reflection.GeneratedProtocolMessageType('VoipVoiceCtp', (_message.Message,), {
  'DESCRIPTOR' : _VOIPVOICECTP,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipVoiceCtp)
  })
_sym_db.RegisterMessage(VoipVoiceCtp)

VoipMediaProfile = _reflection.GeneratedProtocolMessageType('VoipMediaProfile', (_message.Message,), {
  'DESCRIPTOR' : _VOIPMEDIAPROFILE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipMediaProfile)
  })
_sym_db.RegisterMessage(VoipMediaProfile)

VoiceServiceProfile = _reflection.GeneratedProtocolMessageType('VoiceServiceProfile', (_message.Message,), {
  'DESCRIPTOR' : _VOICESERVICEPROFILE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoiceServiceProfile)
  })
_sym_db.RegisterMessage(VoiceServiceProfile)

RtpProfile = _reflection.GeneratedProtocolMessageType('RtpProfile', (_message.Message,), {
  'DESCRIPTOR' : _RTPPROFILE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.RtpProfile)
  })
_sym_db.RegisterMessage(RtpProfile)

PptpPotsUni = _reflection.GeneratedProtocolMessageType('PptpPotsUni', (_message.Message,), {
  'DESCRIPTOR' : _PPTPPOTSUNI,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.PptpPotsUni)
  })
_sym_db.RegisterMessage(PptpPotsUni)

SipConfig = _reflection.GeneratedProtocolMessageType('SipConfig', (_message.Message,), {
  'DESCRIPTOR' : _SIPCONFIG,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.SipConfig)
  })
_sym_db.RegisterMessage(SipConfig)

SipUserData = _reflection.GeneratedProtocolMessageType('SipUserData', (_message.Message,), {
  'DESCRIPTOR' : _SIPUSERDATA,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.SipUserData)
  })
_sym_db.RegisterMessage(SipUserData)

SipAgentConfig = _reflection.GeneratedProtocolMessageType('SipAgentConfig', (_message.Message,), {
  'DESCRIPTOR' : _SIPAGENTCONFIG,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.SipAgentConfig)
  })
_sym_db.RegisterMessage(SipAgentConfig)

NetworkDialPlan = _reflection.GeneratedProtocolMessageType('NetworkDialPlan', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKDIALPLAN,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.NetworkDialPlan)
  })
_sym_db.RegisterMessage(NetworkDialPlan)

UsernameAndPassword = _reflection.GeneratedProtocolMessageType('UsernameAndPassword', (_message.Message,), {
  'DESCRIPTOR' : _USERNAMEANDPASSWORD,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.UsernameAndPassword)
  })
_sym_db.RegisterMessage(UsernameAndPassword)

SipResponseTable = _reflection.GeneratedProtocolMessageType('SipResponseTable', (_message.Message,), {
  'DESCRIPTOR' : _SIPRESPONSETABLE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.SipResponseTable)
  })
_sym_db.RegisterMessage(SipResponseTable)

DialPlanTable = _reflection.GeneratedProtocolMessageType('DialPlanTable', (_message.Message,), {
  'DESCRIPTOR' : _DIALPLANTABLE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.DialPlanTable)
  })
_sym_db.RegisterMessage(DialPlanTable)

VoipFeatureAccessCodes = _reflection.GeneratedProtocolMessageType('VoipFeatureAccessCodes', (_message.Message,), {
  'DESCRIPTOR' : _VOIPFEATUREACCESSCODES,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipFeatureAccessCodes)
  })
_sym_db.RegisterMessage(VoipFeatureAccessCodes)

VoipApplicationServiceProfile = _reflection.GeneratedProtocolMessageType('VoipApplicationServiceProfile', (_message.Message,), {
  'DESCRIPTOR' : _VOIPAPPLICATIONSERVICEPROFILE,
  '__module__' : 'voltha_protos.voip_system_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_system_profile.VoipApplicationServiceProfile)
  })
_sym_db.RegisterMessage(VoipApplicationServiceProfile)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: voltha_protos/voip_user_profile.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='voltha_protos/voip_user_profile.proto',
  package='voip_user_profile',
  syntax='proto3',
  serialized_options=b'\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profile',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%voltha_protos/voip_user_profile.proto\x12\x11voip_user_profile\x1a\x1cgoogle/api/annotations.proto\"b\n\x16VoipUserProfileRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12;\n\x0fvoipUserProfile\x18\x02 \x01(\x0b\x32\".voip_user_profile.VoipUserProfile\"\xa7\x01\n\x0fVoipUserProfile\x12\x1c\n\x14voipSystemProfileKey\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x0e\n\x06\x64omain\x18\x04 \x01(\t\x12\r\n\x05proxy\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\r\x12\x16\n\x0esipDisplayName\x18\x07 \x01(\t\x12\r\n\x05realm\x18\x08 \x01(\tBb\n%org.opencord.voltha.voip_user_profileZ9github.com/opencord/voltha-protos/v5/go/voip_user_profileb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_VOIPUSERPROFILEREQUEST = _descriptor.Descriptor(
  name='VoipUserProfileRequest',
  full_name='voip_user_profile.VoipUserProfileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='voip_user_profile.VoipUserProfileRequest.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='voipUserProfile', full_name='voip_user_profile.VoipUserProfileRequest.voipUserProfile', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=90,
  serialized_end=188,
)


_VOIPUSERPROFILE = _descriptor.Descriptor(
  name='VoipUserProfile',
  full_name='voip_user_profile.VoipUserProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='voipSystemProfileKey', full_name='voip_user_profile.VoipUserProfile.voipSystemProfileKey', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='username', full_name='voip_user_profile.VoipUserProfile.username', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='password', full_name='voip_user_profile.VoipUserProfile.password', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='domain', full_name='voip_user_profile.VoipUserProfile.domain', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='proxy', full_name='voip_user_profile.VoipUserProfile.proxy', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='voip_user_profile.VoipUserProfile.port', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sipDisplayName', full_name='voip_user_profile.VoipUserProfile.sipDisplayName', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='realm', full_name='voip_user_profile.VoipUserProfile.realm', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=358,
)

_VOIPUSERPROFILEREQUEST.fields_by_name['voipUserProfile'].message_type = _VOIPUSERPROFILE
DESCRIPTOR.message_types_by_name['VoipUserProfileRequest'] = _VOIPUSERPROFILEREQUEST
DESCRIPTOR.message_types_by_name['VoipUserProfile'] = _VOIPUSERPROFILE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VoipUserProfileRequest = _reflection.GeneratedProtocolMessageType('VoipUserProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _VOIPUSERPROFILEREQUEST,
  '__module__' : 'voltha_protos.voip_user_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_user_profile.VoipUserProfileRequest)
  })
_sym_db.RegisterMessage(VoipUserProfileRequest)

VoipUserProfile = _reflection.GeneratedProtocolMessageType('VoipUserProfile', (_message.Message,), {
  'DESCRIPTOR' : _VOIPUSERPROFILE,
  '__module__' : 'voltha_protos.voip_user_profile_pb2'
  # @@protoc_insertion_point(class_scope:voip_user_profile.VoipUserProfile)
  })
_sym_db.RegisterMessage(VoipUserProfile)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
